@@ -22,11 +22,10 @@
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */
 
-#include "i_option.h"
+#include "client/base/i_option.h"
 
 using namespace Mysql::Tools::Base::Options;
 
 uint32 I_option::last_optid = 256;
 
-I_option::~I_option()
-{}
+I_option::~I_option() {}
